[![Build Status](https://travis-ci.com/DiamondLightSource/CrystalMatch.svg?branch=master)](https://travis-ci.com/DiamondLightSource/CrystalMatch)
[![Coverage Status](https://coveralls.io/repos/github/DiamondLightSource/CrystalMatch/badge.svg?branch=master)](https://coveralls.io/github/DiamondLightSource/CrystalMatch?branch=master)

VMXi Crystal Image Matching Readme
==================================

Background
----------
Details about the purpose of the VMXi Crystal Image Matching Program

* [The VMXi Beamline](docs/vmxi.md)
* [The Problem of Feature Tracking](docs/tracking.md)

User Guide
----------
This section is a guide for users of the application

Developer Guide
---------------
This section serves as an introduction for developers who are interested in maintaining or extending the Diamond Light Source (DLS) VMXi beamline crystal image matching application. The documents should be read in order
 
* [Code Use Instructions](docs/setup.md)
* [The Solution](docs/solution.md)